ApiClientInterface class abstract
Interface for HTTP API client operations.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String endpoint, {bool includeToken = true, RequestOptions? options}) → Future< CustomApiResponse> -
Sends a DELETE request to
endpoint. -
get(
String endpoint, {bool includeToken = true, RequestOptions? options}) → Future< CustomApiResponse> -
Sends a GET request to
endpoint. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
String endpoint, dynamic data, {bool includeToken = true, bool isMultipart = false, RequestOptions? options}) → Future< CustomApiResponse> -
Sends a PATCH request to
endpointwithdata. -
post(
String endpoint, dynamic data, {bool includeToken = true, bool isMultipart = false, RequestOptions? options}) → Future< CustomApiResponse> -
Sends a POST request to
endpointwithdata. -
put(
String endpoint, dynamic data, {bool includeToken = true, bool isMultipart = false, RequestOptions? options}) → Future< CustomApiResponse> -
Sends a PUT request to
endpointwithdata. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited