CancellableRequest<T> class
A request that can be cancelled by closing the underlying HTTP client.
Constructors
-
CancellableRequest(Client _client, Future<
T> future)
Properties
-
future
→ Future<
T> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCancelled → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited