HttpService class

Low-level HTTP service for sending requests.

Constructors

HttpService(String baseUrl)

Properties

baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMultipartRequest(String method, Uri url, {dynamic data, Map<String, String>? headers, Client? client}) Future<Response>
sendRequest(String method, String endpoint, {dynamic data, Map<String, String>? headers, bool isMultipart = false, Duration? timeout, String? baseUrlOverride}) CancellableRequest<Response>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

requestTimeout → const Duration