InterceptedRequest class

Result of RequestInterceptor.onRequest. Use to override request parts.

Constructors

InterceptedRequest({required String method, required String endpoint, dynamic data, Map<String, String>? headers, bool isMultipart = false})
const

Properties

data → dynamic
final
endpoint String
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
final
isMultipart bool
final
method String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited