ResponseHandler class

Implemented types

Constructors

ResponseHandler()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getErrorMessage(dynamic error) String
handleResponse(Response res) String?
Returns an error message if the response indicates failure, null otherwise.
override
isHtmlOrTextResponse(String responseBody) bool
Returns true if the response body appears to be HTML or plain text (not JSON).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited