ApiClientInterface class abstract

Implementers

Constructors

ApiClientInterface()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String endpoint, {bool includeToken = true, RequestOptions? options}) Future<CustomApiResponse>
get(String endpoint, {bool includeToken = true, RequestOptions? options}) Future<CustomApiResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(String endpoint, dynamic data, {bool includeToken = true, bool isMultipart = false, RequestOptions? options}) Future<CustomApiResponse>
post(String endpoint, dynamic data, {bool includeToken = true, bool isMultipart = false, RequestOptions? options}) Future<CustomApiResponse>
put(String endpoint, dynamic data, {bool includeToken = true, bool isMultipart = false, RequestOptions? options}) Future<CustomApiResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited