CustomApiResponse class

Standard API response wrapper for consistent handling across calls.

Constructors

CustomApiResponse({required int statusCode, required Map<String, String> headers, required dynamic data, required bool isSuccess, String? errorMessage})

Properties

data → dynamic
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
isSuccess bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited