ResponseInterceptor class
Intercepts a response after it is received. Return modified CustomApiResponse or null to keep original.
Constructors
- ResponseInterceptor()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onResponse(
Response rawResponse, CustomApiResponse parsedResponse) → Future< CustomApiResponse?> - Called after each response. Modify and return the response.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited